(***********************************************************************)
(*                                                                     *)
(*                             Active-DVI                              *)
(*                                                                     *)
(*                   Projet Cristal, INRIA Rocquencourt                *)
(*                                                                     *)
(*  Copyright 2002 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the GNU Lesser General Public License.          *)
(*                                                                     *)
(*  Jun Furuse, Didier Rmy and Pierre Weis.                           *)
(*  Contributions by Roberto Di Cosmo, Didier Le Botlan,               *)
(*  Xavier Leroy, and Alan Schmitt.                                    *)
(*                                                                     *)
(*  Based on Mldvi by Alexandre Miquel.                                *)
(***********************************************************************)

(* $Id: shot.mli,v 1.5 2004/03/04 17:27:44 weis Exp $ *)

type x = int and y = int and w = int and h = int;;

val save_page_area_image_file : Misc.file_name -> x -> y -> w -> h -> unit;;
val save_page_area_image : x -> y -> w -> h -> unit;;
val save_page_image_file : Misc.file_name -> unit;;
val save_page_image : unit -> unit;;
